#!/usr/bin/env python


import optparse
import os
import sys

version = '.'.join([str(x) for x in sys.version_info[:2]])
sys.path.append('/usr/local/lib/python%s/site-packages' % version)
sys.path.append('/usr/local/lib64/python%s/site-packages' % version)

from syslog import syslog, openlog, LOG_ERR, LOG_INFO
import subprocess
import tempfile
import logging
import rrdtool
import capd
import operator

openlog('nnabackend')

if os.geteuid() == 0:
    import pwd,grp
    target_uid = pwd.getpwnam('nna').pw_uid
    target_gid = grp.getgrnam('nnacmd').gr_gid
    os.setegid(target_gid)
    os.seteuid(target_uid)

def parse_args():
    
    usage = '%prog --directory <directory> --port <port>'
    parser = optparse.OptionParser(usage=usage)
    
    parser.add_option('--directory', help='Directory the flow records will be recorded to.')
    parser.add_option('--port', type='int', help='Port that will be listened on for the flow records.')
    
    options, args = parser.parse_args()
    
    if not options.directory:
        parser.error("--directory is a required flag.")
    if not options.port:
        parser.error("--port is a required flag.")
    
    return options

def create_bandwidth_db(directory, name='bandwidth.rrd'):
    '''Creates the bandwidth DB for the source'''
    rrdtool.create( os.path.join(directory, name),
                    '--no-overwrite',
                    '--step', '300',
                    'DS:flows:GAUGE:600:0:U',
                    'DS:bytes:GAUGE:600:0:U',
                    'DS:packets:GAUGE:600:0:U',
                    'DS:bps:GAUGE:600:0:U',
                    'DS:pps:GAUGE:600:0:U',
                    'DS:bpp:GAUGE:600:0:U',
                    'RRA:AVERAGE:0.5:1:17531',
                    'RRA:AVERAGE:0.5:12:4380',
                    'RRA:AVERAGE:0.5:288:365',
                    'RRA:HWPREDICT:1440:0.1:0.0035:288' )

def create_source_resources(directory):
    '''Creates the folder for the flows to be written to.'''
    try:
        os.makedirs(directory)
    except OSError, e:
        syslog(LOG_INFO, str(e))
    
    flowdir = os.path.join(directory, 'flows')
    try:
        os.mkdir(os.path.join(flowdir))
    except OSError, e:
        syslog(LOG_INFO, str(e))
    
    try:
        create_bandwidth_db(directory)
    except rrdtool.error, e:
        logging.debug('RRD already exists.')
    except Exception, e:
        logging.exception(e)
        syslog(LOG_ERR, str(e))

def no_existing_infrastructure_for(directory):
    '''Checks to see if there is existing created infrastructure for
    a given directory.'''
    flows = os.path.join(directory, 'flows')
    bandwidth = os.path.join(directory, 'bandwidth.rrd')
    bools = [not os.path.isdir(x) for x in [directory, flows, bandwidth]]
    if not reduce(operator.or_, bools):
        return False
    else:
        return True

def firewall_is_not_open_on(port):
    LIST = ['sudo', '/sbin/iptables', '--list']
    get_list = subprocess.Popen(LIST, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    get_list.wait()
    
    for line in get_list.stdout.readlines():
        if str(port) in line:
            return False
    return True

def open_firewall_port(port):
    IPTABLES    = '/sbin/iptables'
    RULE        = ['INPUT','-p','udp','-j','ACCEPT','--dport']
    new_port    = str(port)
    ADDRULE     = ['sudo' , IPTABLES , '-I' ] + RULE + [ new_port ]
    print ' '.join(ADDRULE)
    apply_rule = subprocess.Popen(ADDRULE)
    apply_rule.wait()
    print 'Saving...'
    save_rules = subprocess.Popen(['sudo','/etc/init.d/iptables','save'])
    save_rules.wait()

def main():
    
    options = parse_args()
    
    #~ Do we need to create the directory structure for this source?
    if no_existing_infrastructure_for(options.directory):
        create_source_resources(options.directory)
    
    #~ Do we need to open the firewall?
    if firewall_is_not_open_on(options.port):
        open_firewall_port(options.port)
    
    
if __name__ == '__main__':
    try:
        main()
    except Exception, e:
        print str(e)
        syslog(LOG_ERR, str(e))
